==> graphql-web-lite-16.6.0-2.tgz: package/validation/rules/FieldsOnCorrectTypeRule.js <==
var jsutils_didYouMean = require("../../jsutils/didYouMean.js");

var jsutils_naturalCompare = require("../../jsutils/naturalCompare.js");

var jsutils_suggestionList = require("../../jsutils/suggestionList.js");

var type_definition = require("../../type/definition.js");

var shared = require("../../shared.js");

exports.FieldsOnCorrectTypeRule = function FieldsOnCorrectTypeRule(context) {
  return {
    Field(node) {
      const type = context.getParentType();
      if (type) {
        if (!context.getFieldDef()) {
          const schema = context.getSchema();
          const fieldName = node.name.value;
          let suggestion = jsutils_didYouMean.didYouMean("to use an inline fragment on", function getSuggestedTypeNames(schema, type, fieldName) {
            if (!type_definition.isAbstractType(type)) {
              return [];
            }
            const suggestedTypes = new Set;
            const usageCount = Object.create(null);
            for (const possibleType of schema.getPossibleTypes(type)) {
              if (!possibleType.getFields()[fieldName]) {
                continue;
              }
              suggestedTypes.add(possibleType);
              usageCount[possibleType.name] = 1;
              for (const possibleInterface of possibleType.getInterfaces()) {
                var _usageCount$possibleI;
                if (!possibleInterface.getFields()[fieldName]) {
                  continue;
                }
                suggestedTypes.add(possibleInterface);
                usageCount[possibleInterface.name] = (null !== (_usageCount$possibleI = usageCount[possibleInterface.name]) && void 0 !== _usageCount$possibleI ? _usageCount$possibleI : 0) + 1;
              }
            }
            return [ ...suggestedTypes ].sort(((typeA, typeB) => {
              const usageCountDiff = usageCount[typeB.name] - usageCount[typeA.name];
              if (0 !== usageCountDiff) {
                return usageCountDiff;
              }
              if (type_definition.isInterfaceType(typeA) && schema.isSubType(typeA, typeB)) {
                return -1;
              }
              if (type_definition.isInterfaceType(typeB) && schema.isSubType(typeB, typeA)) {
                return 1;
              }
              return jsutils_naturalCompare.naturalCompare(typeA.name, typeB.name);
            })).map((x => x.name));
          }(schema, type, fieldName));
          if ("" === suggestion) {
            suggestion = jsutils_didYouMean.didYouMean(function getSuggestedFieldNames(type, fieldName) {
              if (type_definition.isObjectType(type) || type_definition.isInterfaceType(type)) {
                const possibleFieldNames = Object.keys(type.getFields());
                return jsutils_suggestionList.suggestionList(fieldName, possibleFieldNames);
              }
              return [];
            }(type, fieldName));
          }
          context.reportError(new shared.GraphQLError(`Cannot query field "${fieldName}" on type "${type.name}".` + suggestion, {
            nodes: node
          }));
        }
      }
    }
  };
};

==> graphql-web-lite-16.6.0-4.tgz: package/validation/rules/FieldsOnCorrectTypeRule.js <==
var jsutils_didYouMean = require("../../jsutils/didYouMean.js");

var jsutils_naturalCompare = require("../../jsutils/naturalCompare.js");

var jsutils_suggestionList = require("../../jsutils/suggestionList.js");

var type_definition = require("../../type/definition.js");

var graphql_web = require("@0no-co/graphql.web");

exports.FieldsOnCorrectTypeRule = function FieldsOnCorrectTypeRule(context) {
  return {
    Field(node) {
      const type = context.getParentType();
      if (type) {
        if (!context.getFieldDef()) {
          const schema = context.getSchema();
          const fieldName = node.name.value;
          let suggestion = jsutils_didYouMean.didYouMean("to use an inline fragment on", function getSuggestedTypeNames(schema, type, fieldName) {
            if (!type_definition.isAbstractType(type)) {
              return [];
            }
            const suggestedTypes = new Set;
            const usageCount = Object.create(null);
            for (const possibleType of schema.getPossibleTypes(type)) {
              if (!possibleType.getFields()[fieldName]) {
                continue;
              }
              suggestedTypes.add(possibleType);
              usageCount[possibleType.name] = 1;
              for (const possibleInterface of possibleType.getInterfaces()) {
                var _usageCount$possibleI;
                if (!possibleInterface.getFields()[fieldName]) {
                  continue;
                }
                suggestedTypes.add(possibleInterface);
                usageCount[possibleInterface.name] = (null !== (_usageCount$possibleI = usageCount[possibleInterface.name]) && void 0 !== _usageCount$possibleI ? _usageCount$possibleI : 0) + 1;
              }
            }
            return [ ...suggestedTypes ].sort(((typeA, typeB) => {
              const usageCountDiff = usageCount[typeB.name] - usageCount[typeA.name];
              if (0 !== usageCountDiff) {
                return usageCountDiff;
              }
              if (type_definition.isInterfaceType(typeA) && schema.isSubType(typeA, typeB)) {
                return -1;
              }
              if (type_definition.isInterfaceType(typeB) && schema.isSubType(typeB, typeA)) {
                return 1;
              }
              return jsutils_naturalCompare.naturalCompare(typeA.name, typeB.name);
            })).map((x => x.name));
          }(schema, type, fieldName));
          if ("" === suggestion) {
            suggestion = jsutils_didYouMean.didYouMean(function getSuggestedFieldNames(type, fieldName) {
              if (type_definition.isObjectType(type) || type_definition.isInterfaceType(type)) {
                const possibleFieldNames = Object.keys(type.getFields());
                return jsutils_suggestionList.suggestionList(fieldName, possibleFieldNames);
              }
              return [];
            }(type, fieldName));
          }
          context.reportError(new graphql_web.GraphQLError(`Cannot query field "${fieldName}" on type "${type.name}".` + suggestion, {
            nodes: node
          }));
        }
      }
    }
  };
};
